# distpy
An Open Source python module for rapid prototyping Distributed Acoustic Sensing (DAS) processing flows.

It provides massively parallel and scalable DAS interpretation using self-describing branched networks.

See the [Wiki](https://github.com/Schlumberger/distpy/wiki) pages for information on installing, using and developing **distpy**
